package com.zjsgfa.project.zjsgfa.mapper;

import java.util.List;

import com.zjsgfa.framework.aspectj.lang.annotation.DataSource;
import com.zjsgfa.framework.aspectj.lang.enums.DataSourceType;
import com.zjsgfa.project.zjsgfa.domain.Dzgzzb;

/**
 * 地质构造总Mapper接口
 * 
 * @author ruoyi
 * @date 2025-07-08
 */
@DataSource(value = DataSourceType.MASTER)
public interface DzgzzbMapper 
{
    /**
     * 查询地质构造总
     * 
     * @param id 地质构造总主键
     * @return 地质构造总
     */
    public Dzgzzb selectDzgzzbById(Long id);

    /**
     * 查询地质构造总列表
     * 
     * @param dzgzzb 地质构造总
     * @return 地质构造总集合
     */
    public List<Dzgzzb> selectDzgzzbList(Dzgzzb dzgzzb);

    /**
     * 新增地质构造总
     * 
     * @param dzgzzb 地质构造总
     * @return 结果
     */
    public int insertDzgzzb(Dzgzzb dzgzzb);

    /**
     * 修改地质构造总
     * 
     * @param dzgzzb 地质构造总
     * @return 结果
     */
    public int updateDzgzzb(Dzgzzb dzgzzb);

    /**
     * 删除地质构造总
     * 
     * @param id 地质构造总主键
     * @return 结果
     */
    public int deleteDzgzzbById(Long id);

    /**
     * 批量删除地质构造总
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteDzgzzbByIds(Long[] ids);
}
